@@ -208,6 +208,13 @@ sub date_short
         $dt->year;
 }
 
+sub london_date
+{
+    my ($self, $dt) = @_;
+    return if !$dt;
+    $dt->set_time_zone('Europe/London');
+}
+
 sub time_long
 {
     my ($self, $dt) = @_;
@@ -290,7 +297,7 @@ OpusVL::AppKit::RolesFor::Controller::GUI
 
 =head1 VERSION
 
-version 2.25
+version 2.26
 
 =head1 SYNOPSIS
 
